@@ -1,5 +1,4 @@
 use crate::reporters::create_reporter;
-use anyhow::Result as AnyResult;
 use std::collections::HashMap;
 
 use crate::content::ContentCheck;
@@ -11,6 +10,11 @@ pub struct RunOptions {
     pub flip: bool,
     pub reporters: HashMap<String, ReporterConfig>,
 }
+impl Default for RunOptions {
+    fn default() -> Self {
+        RunOptions::build(None, false, Some("console".into()), true)
+    }
+}
 
 impl RunOptions {
     pub fn build(
@@ -18,20 +22,19 @@ impl RunOptions {
         flip: bool,
         reporter: Option<String>,
         verbose: bool,
-    ) -> AnyResult<RunOptions> {
-        let sender = SenderBuilder::build(SenderOptions { dry_run: dry_run });
+    ) -> Self {
+        let sender = SenderBuilder::build(SenderOptions { dry_run });
         let mut reporters = HashMap::new();
         let mut rc = HashMap::new();
         if verbose {
             rc.insert("verbose".to_string(), "true".to_string());
         }
-        reporters.insert(reporter.unwrap_or("console".to_string()), rc);
-        let run_opts = RunOptions {
-            sender: sender,
-            reporters: reporters,
-            flip: flip,
-        };
-        Ok(run_opts)
+        reporters.insert(reporter.unwrap_or_else(|| "console".to_string()), rc);
+        RunOptions {
+            sender,
+            reporters,
+            flip,
+        }
     }
 }
 pub struct SequenceRunner<'a> {
@@ -47,28 +50,28 @@ impl<'a> SequenceRunner<'a> {
         reporters: HashMap<String, ReporterConfig>,
     ) -> Self {
         SequenceRunner {
-            flip: flip,
-            sender: sender,
-            reporters: reporters.clone(),
+            flip,
+            sender,
+            reporters,
         }
     }
 
     pub fn from_opts(run_opts: &'a RunOptions) -> Self {
         SequenceRunner {
-            flip: run_opts.flip.clone(),
+            flip: run_opts.flip,
             sender: run_opts.sender.as_ref(),
             reporters: run_opts.reporters.clone(),
         }
     }
 
-    pub fn run(&mut self, context: &mut Context, sequence: &[Interaction]) -> RunnerReport {
+    pub fn run(&self, context: &mut Context, sequence: &[Interaction]) -> RunnerReport {
         let mut reporter = create_reporter(&self.reporters);
         let results = sequence
             .iter()
             .map(|interaction| {
                 let checker = ContentCheck::new(self.sender);
                 reporter.start(interaction);
-                let res = checker.perform(context, &interaction);
+                let res = checker.perform(context, interaction);
                 reporter.report(interaction, &res);
                 res
             })
@@ -76,16 +79,13 @@ impl<'a> SequenceRunner<'a> {
 
         reporter.end(sequence, &results);
         let ok = if self.flip {
-            results.iter().all(|r| r.violations.len() > 0)
+            results.iter().all(|r| !r.violations.is_empty())
                 && results.iter().all(|r| r.error.is_none())
         } else {
-            results.iter().all(|r| r.violations.len() == 0)
+            results.iter().all(|r| !r.violations.is_empty())
                 && results.iter().all(|r| r.error.is_none())
         };
-        RunnerReport {
-            ok: ok,
-            results: results,
-        }
+        RunnerReport { ok, results }
     }
 }
 
